@@ -35,8 +35,10 @@
  * Contributor(s):   David Gilbert (for Object Refinery Limited);
  *                   Nina Jeliazkova;
  *
- * Changes
- * -------
+ * $Id: SpiderWebPlot.java,v 1.11.2.14 2007/03/05 13:46:28 mungady Exp $
+ *
+ * Changes (from 28-Jan-2005)
+ * --------------------------
  * 28-Jan-2005 : First cut - missing a few features - still to do:
  *                           - needs tooltips/URL/label generator functions
  *                           - ticks on axes / background grid?
@@ -61,7 +63,6 @@
  * 06-Feb-2007 : Changed getPlotValue() to protected, as suggested in bug 
  *               1605202 (DG);
  * 05-Mar-2007 : Restore clip region correctly (see bug 1667750) (DG);
- * 18-May-2007 : Set dataset for LegendItem (DG);
  *
  */
 
@@ -1099,7 +1100,6 @@ public class SpiderWebPlot extends Plot implements Cloneable, Serializable {
                 Stroke stroke = getSeriesOutlineStroke(series);
                 LegendItem item = new LegendItem(label, description, 
                         null, null, shape, paint, stroke, outlinePaint);
-                item.setDataset(getDataset());
                 result.add(item);
                 series++;
             }
@@ -1338,14 +1338,12 @@ public class SpiderWebPlot extends Plot implements Cloneable, Serializable {
                                    series, cat);
                         } 
                    
-                        Shape area = new Rectangle(
-                                (int) (point.getX() - headW),
+                        Shape area = new Rectangle((int) (point.getX() - headW), 
                                 (int) (point.getY() - headH), 
                                 (int) (headW * 2), (int) (headH * 2));
                         CategoryItemEntity entity = new CategoryItemEntity(
-                                area, tip, url, this.dataset, 
-                                this.dataset.getRowKey(series),
-                                this.dataset.getColumnKey(cat)); 
+                                area, tip, url, this.dataset, series,
+                                this.dataset.getColumnKey(cat), cat); 
                         entities.add(entity);                                
                     }
 
